Documentation
¶
Index ¶
- func DumpNodeNoExit(whatever interface{})
- func DumpNodeWithExit(whatever interface{})
- func GetLocalSourcesPath() string
- func ToJSON(data interface{}) ([]byte, error)
- func ToJSONPretty(data interface{}) ([]byte, error)
- func ToProtoJSON(data interface{}) ([]byte, error)
- func WriteToFile(path string, data []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DumpNodeNoExit ¶ added in v0.2.1
func DumpNodeNoExit(whatever interface{})
DumpNodeNoExit prints a formatted JSON representation of the provided interface without exiting the program. This function is primarily used for debugging purposes.
func DumpNodeWithExit ¶ added in v0.2.1
func DumpNodeWithExit(whatever interface{})
DumpNodeWithExit prints a formatted JSON representation of the provided interface and exits the program. This function is primarily used for debugging purposes.
func GetLocalSourcesPath ¶ added in v0.2.2
func GetLocalSourcesPath() string
GetLocalSourcesPath returns the absolute path to the local sources directory.
func ToJSONPretty ¶
ToJSONPretty returns a pretty-printed JSON representation of the provided interface. This function is primarily used for debugging purposes.
func ToProtoJSON ¶
ToProtoJSON converts a Go struct to its JSON representation.
func WriteToFile ¶
WriteToFile writes the provided data byte array to a file at the provided path.
Types ¶
This section is empty.